==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Test/Gui/Resources/translations/Test_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es-ES" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>Prueba de unidades de FreeCAD</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Fallos y errores</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Descripción</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>&amp;Iniciar</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>&amp;Ayuda</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Acerca de</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Cerrar</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Inactivo</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Progreso</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Restante:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Errores:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Fallos:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Ejecutar:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Prueba</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Selecciona nombre para la prueba</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Help</source>
      <translation>Ayuda</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Introduzca el nombre de un objeto llamable que, cuando sea llamado, devolverá un TestCase. Haga clic en 'Inicio', y se llevará a cabo la prueba ya. 

Haga doble clic en un error en la vista de árbol para ver más información sobre él, incluyendo el seguimiento de la pila.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Acerca de FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer 

FreeCAD UnitTest es parte de FreeCAD y soporta escribir pruebas unitarias para los propios módulos.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Test/Gui/Resources/translations/Test_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es-ES" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>Prueba de unidades de FreeCAD</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Fallos y errores</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Descripción</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>&amp;Iniciar</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>&amp;Ayuda</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Acerca de</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Cerrar</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Inactivo</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Progreso</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Restante:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Errores:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Fallos:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Ejecutar:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Prueba</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Selecciona nombre para la prueba</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Help</source>
      <translation>Ayuda</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Introduzca el nombre de un objeto llamable que, cuando sea llamado, devolverá un TestCase.
Haga clic en 'Inicio', y se llevará a cabo la prueba ya.

Haga doble clic en un error en la vista de árbol para ver más información sobre él, incluyendo el seguimiento de la pila.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Acerca de FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer 

FreeCAD UnitTest es parte de FreeCAD y soporta escribir pruebas unitarias para los propios módulos.</translation>
    </message>
  </context>
</TS>
